import requests
import json

def upload_image(file_path):
    url = "https://pics.sunbangyan.cn/application/upload.php"
    files = {'file': open(file_path, 'rb')}
    
    response = requests.post(url, files=files)
    
    if response.status_code == 200:
        return json.loads(response.text)["url"]
    else:
        return None


from .uploader import upload_file, get_image_url

def main():
    url = "https://pics.sunbangyan.cn/application/upload.php"
    file_path = input("输入文件名或者目录:")

    result = upload_file(url, file_path)
    image_url = get_image_url(result)

    print(f"上传结果：{result}")
    print(f"图片链接：{image_url}")

if __name__ == "__main__":
    main()


from setuptools import setup

setup(
    name='tuchuang',
    version='3.0.0',
    description='一个免费而简单图床',
    author='Python学霸',
    author_email='python@xueba.com',
    packages=['tuchuang'],
    install_requires=['requests', 'json'],
)